summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmclippedbyedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmclippedbyedit.h')
-rw-r--r--kpovmodeler/pmclippedbyedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmclippedbyedit.h b/kpovmodeler/pmclippedbyedit.h
index 5b22f564..9050f406 100644
--- a/kpovmodeler/pmclippedbyedit.h
+++ b/kpovmodeler/pmclippedbyedit.h
@@ -35,12 +35,13 @@ class TQLabel;
class PMClippedByEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMClippedByEdit with parent and name
*/
- PMClippedByEdit( TQWidget* parent, const char* name = 0 );
+ PMClippedByEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQLabel;
public:
/**
- * Creates a PMClippedByEdit with parent and name
+ * Creates a PMClippedByEdit with tqparent and name
*/